"""python_seed.scripts.cli."""

import os
import shutil

import click
import pkg_resources

from .. import version


@click.group(short_help="python-seed CLI")
@click.version_option(version=version, message="%(version)s")
def pyseed():
    """python-seed subcommands."""
    pass


@pyseed.command(short_help="Create new python seed skeleton")
@click.argument("name", type=str, nargs=1)
@click.option(
    "--ci", type=click.Choice(["circleci", "github"]), help="Add CI configuration"
)
def create(name, ci):
    """Create new python seed skeleton."""
    template_dir = pkg_resources.resource_filename("python_seed", "template/module")

    shutil.copytree(template_dir, name)

    if ci:
        template_dir = pkg_resources.resource_filename(
            "python_seed", f"template/ci/.{ci}"
        )
        shutil.copytree(template_dir, f"{name}/.{ci}")

        covconfig = pkg_resources.resource_filename(
            "python_seed", "template/cov/codecov.yml"
        )
        shutil.copy2(covconfig, f"{name}/codecov.yml")

    new_dir = name
    name = name.replace("-", "_")
    for root, _, files in os.walk(new_dir):
        if root.endswith("pyseed"):
            shutil.move(root, root.replace("pyseed", name))

    for root, _, files in os.walk(new_dir):
        for filename in files:
            if filename.endswith(".pyc"):
                continue
            with open(f"{root}/{filename}", "r", encoding="utf-8") as f:
                s = f.read().replace("pyseed", name)

            with open(f"{root}/{filename}", "w", encoding="utf-8") as f:
                f.write(s)



"""pyseed module."""

from setuptools import find_packages, setup

with open("README.md") as f:
    readme = f.read()

# Runtime Requirements.
inst_reqs = ["click"]

# Dev Requirements
extra_reqs = {
    "test": ["pytest", "pytest-cov"],
    "dev": ["pytest", "pytest-cov", "pre-commit"],
}


setup(
    name="pyseed",
    version="0.0.1",
    description=u"An Awesome python module",
    long_description=readme,
    long_description_content_type="text/markdown",
    python_requires=">=3",
    classifiers=[
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    keywords="An Awesome python module",
    author=u"",
    author_email="",
    url="",
    packages=find_packages(exclude=["ez_setup", "examples", "tests"]),
    include_package_data=True,
    zip_safe=False,
    install_requires=inst_reqs,
    extras_require=extra_reqs,
    entry_points={"console_scripts": ["pyseed = pyseed.scripts.cli:pyseed"]},
)
